==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebDropdownHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownHeaderDescription } from "./WebDropdownHeaderDescription";
/**
 * @hidden
 */
var WebDropdownHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDropdownHeaderDescriptionMetadata, _super);
    function WebDropdownHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownHeaderDescriptionMetadata.b = function (a) {
        if (WebDropdownHeaderDescriptionMetadata.a == null) {
            WebDropdownHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDropdownHeaderDescriptionMetadata.c(WebDropdownHeaderDescriptionMetadata.a);
        }
        if (a.k(WebDropdownHeaderDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebDropdownHeaderDescriptionMetadata.a);
    };
    WebDropdownHeaderDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DropdownHeader");
        a.item("__tagNameWC", "String:igc-dropdown-header");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebDropdownHeaderDescriptionMetadata.d = function (a) {
        WebDropdownHeaderDescriptionMetadata.b(a);
        a.ad("WebDropdownHeader", function () { return new WebDropdownHeaderDescription(); });
        a.ac("WebDropdownHeader", WebDropdownHeaderDescriptionMetadata.a);
    };
    WebDropdownHeaderDescriptionMetadata.$t = markType(WebDropdownHeaderDescriptionMetadata, 'WebDropdownHeaderDescriptionMetadata');
    WebDropdownHeaderDescriptionMetadata.a = null;
    return WebDropdownHeaderDescriptionMetadata;
}(Base));
export { WebDropdownHeaderDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebDropdownHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownHeaderDescription } from "./WebDropdownHeaderDescription";
/**
 * @hidden
 */
var WebDropdownHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDropdownHeaderDescriptionMetadata, _super);
    function WebDropdownHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownHeaderDescriptionMetadata.b = function (a) {
        if (WebDropdownHeaderDescriptionMetadata.a == null) {
            WebDropdownHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDropdownHeaderDescriptionMetadata.c(WebDropdownHeaderDescriptionMetadata.a);
        }
        if (a.k(WebDropdownHeaderDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebDropdownHeaderDescriptionMetadata.a);
    };
    WebDropdownHeaderDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DropdownHeader");
        a.item("__tagNameWC", "String:igc-dropdown-header");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebDropdownHeaderDescriptionMetadata.d = function (a) {
        WebDropdownHeaderDescriptionMetadata.b(a);
        a.ae("WebDropdownHeader", function () { return new WebDropdownHeaderDescription(); });
        a.ad("WebDropdownHeader", WebDropdownHeaderDescriptionMetadata.a);
    };
    WebDropdownHeaderDescriptionMetadata.$t = markType(WebDropdownHeaderDescriptionMetadata, 'WebDropdownHeaderDescriptionMetadata');
    WebDropdownHeaderDescriptionMetadata.a = null;
    return WebDropdownHeaderDescriptionMetadata;
}(Base));
export { WebDropdownHeaderDescriptionMetadata };
